# ---------------------------------------------------------
# This script will extract raw data and create plots for 
# NESP MaC Hub Project 4.9 
# https://www.nespmarinecoastal.edu.au/project/4-9/
# Authors: Sophia Volzke and Rebecca Dunlop
# Collaborator: Cormac Booth and SMRU Consulting are the owners of the iPCoD model and the below code

# ---------------------------------------------------------
# iPCoD = interim Population Consequence of Disturbance
# EE = Expert elicitation
# SRW = Southern right whale
# BW = Blue whale
# S1 = Scenario 1 - behavioural disturbance only
# S2 = Scenario 2 - behavioural disturbance + 1 physical injury

# RIGHT WHALES
# - SCENARIO 1 --------------------------------------------------------
# load data: 
load("iPCoD_EE_S1_SRW_Output.rdata") # SRW - Scenario 1

years <- length(dat.out[,1,1])
Undist_mean <- Dist_mean <- Diff_mean <- backtonormal <- max_diff <- 0

for (i in 1:(years-1)){Dist_mean[i] <- mean(dat.out[i,1,])}
for (i in 1:(years-1)){Undist_mean[i] <- mean(dat.out[i,2,])}
for (i in 1:(years-1)){Diff_mean[i] <- mean(dat.out[i,3,])}

# determine maximum difference between disturbed and undisturbed population for each simulation
# for (i in 1:nboot){max_diff[i] <- -min(dat.out[1:years,3,i])}
(max_diff <- apply(dat.out[1:years,3,],1,min))
(backtonormal <- which((apply(dat.out[1:years,3,],1,min))>-.01*mean(dat.out[1,2,])))

# this R file has the functions for creating figures and table of outputs from iPCoD. 
source("SUMMARY_FUNCTIONS_SV.R")

# Are there negative populations in the dat.out object/PCoD projections? If so, how many?
sum(dat.out[,2,]<0,na.rm=T) # number <0 in baseline populations
sum(dat.out[,1,]<0,na.rm=T) # number <0 in impacted populations

### LINE PLOTS ###
# create line plots of baseline and impacted population trajectories over the 25-year simulation
par(mfrow=c(1,3),oma=c(3.5,6,2,1),mar=c(.5,.5,.5,.5), bg = 'white')
LINES(dat.out, simulated.years=2024:(2024+years-2), Dist_mean, Undist_mean, nlines=100) 

# Save P1_Lines_SRW_S1
dev.copy(png, 'P1_Lines_SRW_S1.png', width = 1600, height = 800, res = 150) # save in 1600 x 800
dev.off()

### CUSTOM.TABLE ###
# The following code gives a table for the mean baseline and impacted population size 
# in year 1, 6, 12, 18 and 24, 95% CI and the median population size
# note that time.point=1 is the start year (no possible impact yet)
# time.point=2 means the start of 2nd year, after 1 year of impact
# the user can change the values in "time.points", "percent.CI" and "get.median"

output_table <- CUSTOM.TABLE(dat.out, time.points=c(1:31), percent.CI=95, get.median=F)

# output table as CSV file
write.csv(round(output_table, 3), "SRW_S2_Summary_Stats.csv", row.names=FALSE)

### POP GROWTH ###
data <- as.data.frame(output_table)

growth_rates <- calculate_growth_rate(data)
#print(growth_rates)

# - GROWTH RATES PLOT - 
# Extract the years from the row names
years <- 2024:(2024 + nrow(growth_rates) - 1)
growth_rates$un_impacted_growth_rate_lower
# Define the ylim range 
ylim_range <- c(-0.172, 0.120)

par(mfrow=c(1,2), oma=c(0.5,0.6,0.3,0.5), mar=c(3,3,1.5,0.1), cex.main=1.1, cex.lab=0.9, bg='white')  

# Plot for baseline population (with y-axis)
plot(years, growth_rates$un_impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="% Change in Population Size", 
     main="Baseline Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  
	  
polygon(c(years, rev(years)), c(growth_rates$un_impacted_growth_rate_lower, rev(growth_rates$un_impacted_growth_rate_upper)), 
        col=rgb(0, 0, 1, 0.2), border=NA)
lines(years, growth_rates$un_impacted_growth_rate_mean, col="blue", lwd=2)
abline(h=0, col="grey")

# Plot for impacted population (without y-axis)
plot(years, growth_rates$impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="",  # Remove y-axis label on right panel
     main="Impacted Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  

polygon(c(years, rev(years)), c(growth_rates$impacted_growth_rate_lower, rev(growth_rates$impacted_growth_rate_upper)), 
        col=rgb(1, 0, 0, 0.2), border=NA)
lines(years, growth_rates$impacted_growth_rate_mean, col="red", lwd=2)
abline(h=0, col="grey")

# Save P2_PopGr_SRW_S1
dev.copy(png, 'P2_PopGr_SRW_S1.png', width = 1600, height = 800, res = 150) #save in 1600 x 800
dev.off()




# - SCENARIO 2 --------------------------------------------------------
# load data: 
load("iPCoD_EE_S2_SRW_Output.rdata") # SRW - Scenario 2

years <- length(dat.out[,1,1])
Undist_mean <- Dist_mean <- Diff_mean <- backtonormal <- max_diff <- 0

for (i in 1:(years-1)){Dist_mean[i] <- mean(dat.out[i,1,])}
for (i in 1:(years-1)){Undist_mean[i] <- mean(dat.out[i,2,])}
for (i in 1:(years-1)){Diff_mean[i] <- mean(dat.out[i,3,])}

# determine maximum difference between disturbed and undisturbed population for each simulation
# for (i in 1:nboot){max_diff[i] <- -min(dat.out[1:years,3,i])}
(max_diff <- apply(dat.out[1:years,3,],1,min))
(backtonormal <- which((apply(dat.out[1:years,3,],1,min))>-.01*mean(dat.out[1,2,])))

# this R file has the functions for creating figures and table of outputs from iPCoD. 
source("SUMMARY_FUNCTIONS_SV.R")

# Are there negative populations in the dat.out object/PCoD projections? If so, how many?
sum(dat.out[,2,]<0,na.rm=T) # number <0 in baseline populations
sum(dat.out[,1,]<0,na.rm=T) # number <0 in impacted populations

### LINE PLOTS ###
# create line plots of baseline and impacted population trajectories over the 25-year simulation
par(mfrow=c(1,3),oma=c(3.5,6,2,1),mar=c(.5,.5,.5,.5), bg = 'white')
LINES(dat.out, simulated.years=2024:(2024+years-2), Dist_mean, Undist_mean, nlines=100) 

LINES(dat.out, simulated.years=2024:(2024+years-2), Dist_mean, Undist_mean, nlines=100) 

# Save P1_Lines_SRW_S2
dev.copy(png, 'P1_Lines_SRW_S2.png', width = 1600, height = 800, res = 150) # save in 1600 x 800
dev.off()

### CUSTOM.TABLE ###
# The following code gives a table for the mean baseline and impacted population size 
# in year 1, 6, 12, 18 and 24, 95% CI and the median population size
# note that time.point=1 is the start year (no possible impact yet)
# time.point=2 means the start of 2nd year, after 1 year of impact
# the user can change the values in "time.points", "percent.CI" and "get.median"

output_table <- CUSTOM.TABLE(dat.out, time.points=c(1:31), percent.CI=95, get.median=F)

# output table as "csv" file
write.csv(round(output_table, 3), "SRW_S1_Summary_Stats.csv", row.names=FALSE)

### POP GROWTH ###
data <- as.data.frame(output_table)

growth_rates <- calculate_growth_rate(data)
#print(growth_rates)

# - GROWTH RATES PLOT - 
# Extract the years from the row names
years <- 2024:(2024 + nrow(growth_rates) - 1)

# Define the ylim range 
ylim_range <- c(-0.172, 0.120)

par(mfrow=c(1,2), oma=c(0.5,0.6,0.3,0.5), mar=c(3,3,1.5,0.1), cex.main=1.1, cex.lab=0.9, bg='white')  

# Plot for baseline population (with y-axis)
plot(years, growth_rates$un_impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="% Change in Population Size", 
     main="Baseline Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  
	  
polygon(c(years, rev(years)), c(growth_rates$un_impacted_growth_rate_lower, rev(growth_rates$un_impacted_growth_rate_upper)), 
        col=rgb(0, 0, 1, 0.2), border=NA)
lines(years, growth_rates$un_impacted_growth_rate_mean, col="blue", lwd=2)
abline(h=0, col="grey")

# Plot for impacted population (without y-axis)
plot(years, growth_rates$impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="",  # Remove y-axis label on right panel
     main="Impacted Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  

polygon(c(years, rev(years)), c(growth_rates$impacted_growth_rate_lower, rev(growth_rates$impacted_growth_rate_upper)), 
        col=rgb(1, 0, 0, 0.2), border=NA)
lines(years, growth_rates$impacted_growth_rate_mean, col="red", lwd=2)
abline(h=0, col="grey")

# Save P2_PopGr_SRW_S2
dev.copy(png, 'P2_PopGr_SRW_S2.png', width = 1600, height = 800, res = 150) #save in 1600 x 800
dev.off()




# BLUE WHALES
# - SCENARIO 1 --------------------------------------------------------

# load data: 
 load("iPCoD_EE_S1_BW_Output.rdata") # BW - Scenario 1

years <- length(dat.out[,1,1])
Undist_mean <- Dist_mean <- Diff_mean <- backtonormal <- max_diff <- 0

for (i in 1:(years-1)){Dist_mean[i] <- mean(dat.out[i,1,])}
for (i in 1:(years-1)){Undist_mean[i] <- mean(dat.out[i,2,])}
for (i in 1:(years-1)){Diff_mean[i] <- mean(dat.out[i,3,])}

# determine maximum difference between disturbed and undisturbed population for each simulation
# for (i in 1:nboot){max_diff[i] <- -min(dat.out[1:years,3,i])}
(max_diff <- apply(dat.out[1:years,3,],1,min))
(backtonormal <- which((apply(dat.out[1:years,3,],1,min))>-.01*mean(dat.out[1,2,])))

# this R file has the functions for creating figures and table of outputs from iPCoD. 
source("SUMMARY_FUNCTIONS_SV.R")

# Are there negative populations in the dat.out object/PCoD projections? If so, how many?
sum(dat.out[,2,]<0,na.rm=T) # number <0 in baseline populations
sum(dat.out[,1,]<0,na.rm=T) # number <0 in impacted populations

### LINE PLOTS ###
# create line plots of baseline and impacted population trajectories over the 25-year simulation
par(mfrow=c(1,3),oma=c(3.5,6,2,1),mar=c(.5,.5,.5,.5), bg = 'white')
LINES(dat.out, simulated.years=2024:(2024+years-2), Dist_mean, Undist_mean, nlines=100) 

# Save P1_Lines_BW_S1
dev.copy(png, 'P1_Lines_BW_S1.png', width = 1600, height = 800, res = 150) # save in 1600 x 800
dev.off()

### CUSTOM.TABLE ###
# The following code gives a table for the mean baseline and impacted population size 
# in year 1, 6, 12, 18 and 24, 95% CI and the median population size
# note that time.point=1 is the start year (no possible impact yet)
# time.point=2 means the start of 2nd year, after 1 year of impact
# the user can change the values in "time.points", "percent.CI" and "get.median"

output_table <- CUSTOM.TABLE(dat.out, time.points=c(1:31), percent.CI=95, get.median=F)

# output table as "csv" file
write.csv(round(output_table, 3), "BW_S1_Summary_Stats.csv", row.names=FALSE)

### POP GROWTH ###
data <- as.data.frame(output_table)

growth_rates <- calculate_growth_rate(data)
#print(growth_rates)

# - GROWTH RATES PLOT - 
# Extract the years from the row names
years <- 2024:(2024 + nrow(growth_rates) - 1)

# Define the ylim range 
ylim_range <- c(-0.172, 0.120)

par(mfrow=c(1,2), oma=c(0.5,0.6,0.3,0.5), mar=c(3,3,1.5,0.1), cex.main=1.1, cex.lab=0.9, bg='white')  

# Plot for baseline population (with y-axis)
plot(years, growth_rates$un_impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="% Change in Population Size", 
     main="Baseline Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  
	  
polygon(c(years, rev(years)), c(growth_rates$un_impacted_growth_rate_lower, rev(growth_rates$un_impacted_growth_rate_upper)), 
        col=rgb(0, 0, 1, 0.2), border=NA)
lines(years, growth_rates$un_impacted_growth_rate_mean, col="blue", lwd=2)
abline(h=0, col="grey")

# Plot for impacted population (without y-axis)
plot(years, growth_rates$impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="",  # Remove y-axis label on right panel
     main="Impacted Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  

polygon(c(years, rev(years)), c(growth_rates$impacted_growth_rate_lower, rev(growth_rates$impacted_growth_rate_upper)), 
        col=rgb(1, 0, 0, 0.2), border=NA)
lines(years, growth_rates$impacted_growth_rate_mean, col="red", lwd=2)
abline(h=0, col="grey")

# Save P2_PopGr_BW_S1
dev.copy(png, 'P2_PopGr_BW_S1.png', width = 1600, height = 800, res = 150) #save in 1600 x 800
dev.off()



# - SCENARIO 2 --------------------------------------------------------
# load data: 
load("iPCoD_EE_S2_BW_Output.rdata") # BW - Scenario 2

years <- length(dat.out[,1,1])
Undist_mean <- Dist_mean <- Diff_mean <- backtonormal <- max_diff <- 0

for (i in 1:(years-1)){Dist_mean[i] <- mean(dat.out[i,1,])}
for (i in 1:(years-1)){Undist_mean[i] <- mean(dat.out[i,2,])}
for (i in 1:(years-1)){Diff_mean[i] <- mean(dat.out[i,3,])}

# determine maximum difference between disturbed and undisturbed population for each simulation
# for (i in 1:nboot){max_diff[i] <- -min(dat.out[1:years,3,i])}
(max_diff <- apply(dat.out[1:years,3,],1,min))
(backtonormal <- which((apply(dat.out[1:years,3,],1,min))>-.01*mean(dat.out[1,2,])))

# this R file has the functions for creating figures and table of outputs from iPCoD. 
source("SUMMARY_FUNCTIONS_SV.R")

# Are there negative populations in the dat.out object/PCoD projections? If so, how many?
sum(dat.out[,2,]<0,na.rm=T) # number <0 in baseline populations
sum(dat.out[,1,]<0,na.rm=T) # number <0 in impacted populations

### LINE PLOTS ###
# create line plots of baseline and impacted population trajectories over the 25-year simulation
par(mfrow=c(1,3),oma=c(3.5,6,2,1),mar=c(.5,.5,.5,.5), bg = 'white')
LINES(dat.out, simulated.years=2024:(2024+years-2), Dist_mean, Undist_mean, nlines=100)  

# Save P1_Lines_BW_S2
dev.copy(png, 'P1_Lines_BW_S2.png', width = 1600, height = 800, res = 150) # save in 1600 x 800
dev.off()

### CUSTOM.TABLE ###
# The following code gives a table for the mean baseline and impacted population size 
# in year 1, 6, 12, 18 and 24, 95% CI and the median population size
# note that time.point=1 is the start year (no possible impact yet)
# time.point=2 means the start of 2nd year, after 1 year of impact
# the user can change the values in "time.points", "percent.CI" and "get.median"

output_table <- CUSTOM.TABLE(dat.out, time.points=c(1:31), percent.CI=95, get.median=F)

# output table as "csv" file
write.csv(round(output_table, 3), "BW_S2_Summary_Stats.csv", row.names=FALSE)

### POP GROWTH ###
data <- as.data.frame(output_table)

growth_rates <- calculate_growth_rate(data)
#print(growth_rates)

# - GROWTH RATES PLOT - 
# Extract the years from the row names
years <- 2024:(2024 + nrow(growth_rates) - 1)

# Define the ylim range 
ylim_range <- c(-0.172, 0.120)

par(mfrow=c(1,2), oma=c(0.5,0.6,0.3,0.5), mar=c(3,3,1.5,0.1), cex.main=1.1, cex.lab=0.9, bg='white')  

# Plot for baseline population (with y-axis)
plot(years, growth_rates$un_impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="% Change in Population Size", 
     main="Baseline Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  
	  
polygon(c(years, rev(years)), c(growth_rates$un_impacted_growth_rate_lower, rev(growth_rates$un_impacted_growth_rate_upper)), 
        col=rgb(0, 0, 1, 0.2), border=NA)
lines(years, growth_rates$un_impacted_growth_rate_mean, col="blue", lwd=2)
abline(h=0, col="grey")

# Plot for impacted population (without y-axis)
plot(years, growth_rates$impacted_growth_rate_mean, type="n", cex.axis=0.92, ylim=ylim_range, 
     xlab="Year", ylab="",  # Remove y-axis label on right panel
     main="Impacted Population", cex.main=1.1, font.main=1, cex.lab=1, mgp=c(2.2, 0.7, 0))  

polygon(c(years, rev(years)), c(growth_rates$impacted_growth_rate_lower, rev(growth_rates$impacted_growth_rate_upper)), 
        col=rgb(1, 0, 0, 0.2), border=NA)
lines(years, growth_rates$impacted_growth_rate_mean, col="red", lwd=2)
abline(h=0, col="grey")

# Save P2_PopGr_BW_S2
dev.copy(png, 'P2_PopGr_BW_S2.png', width = 1600, height = 800, res = 150) # Save in 1600 x 800
dev.off()


